==> tecfy_core_package-0.1.102.tar.gz: lib/views/general/local_records.page.dart <==
part of tecfy_core_client_package;

class LocalRecordsPage extends StatefulWidget {
  @override
  _LocalRecordsPageState createState() => _LocalRecordsPageState();
}

class _LocalRecordsPageState extends AppState<LocalRecordsPage> {
  List<dynamic> _data;
  ScrollController _scrollController;
  @override
  initState() {
    _scrollController = ScrollController();
    TecfySyncService.getLocalRecords().then((d) {
      _data = d;
      setState(() {});
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['id']);
        _data = await TecfySyncService.getLocalRecords();
        setState(() {});
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, AppLocale.translate(context, 'Local Database'),
        appBarActions: [
          TecfySyncService.isSyncing
              ? CircularProgressIndicator()
              : IconButton(
                  tooltip: trans('Sync'),
                  icon: Icon(Icons.sync_alt),
                  onPressed: () async {
                    TecfySyncService.isSyncing = true;
                    setState(() {});
                    var result = await TecfySyncService.syncNow(context:context);
                    TecfySyncService.isSyncing = false;
                    if (result) {
                      AppNavigator.showMessage(context, 'تمت العملية بنجاح',
                          type: MessageType.success);
                      _data = await TecfySyncService.getLocalRecords();
                    } else {
                      AppNavigator.showMessage(context, 'Error',
                          message: 'خطأ اثناء المزامنه مع السيرفر',
                          type: MessageType.error);
                    }
                    setState(() {});
                  })
        ],
        child: _data == null
            ? Center(child: CircularProgressIndicator())
            : Scrollbar(
                isAlwaysShown: true,
                showTrackOnHover: true,
                controller: _scrollController,
                child: SingleChildScrollView(
                  controller: _scrollController,
                  child: DataTable(
                    showCheckboxColumn: true,
                    sortColumnIndex: 0,
                    sortAscending: false,
                    columns: [
                      DataColumn(label: Text(trans('Entity')), numeric: false),
                      DataColumn(label: Text(trans('Count')), numeric: true),
                    ],
                    rows: _data
                        .map<DataRow>((d) => DataRow(
                              cells: [
                                DataCell(
                                    Text(d['entityName'] ?? d['entity'] ?? ''),
                                    onTap: () => onTab(d)),
                                DataCell(Text(d['count'].toString()),
                                    onTap: () => onTab(d)),
                                // DataCell(Text(d['message'] ?? ''),
                                //     onTap: () => onTab(d)),
                              ],
                            ))
                        .toList(),
                  ),
                ),
              ));
  }
}

==> tecfy_core_package-1.0.1.tar.gz: lib/views/general/local_records.page.dart <==
part of tecfy_core_client_package;

class LocalRecordsPage extends StatefulWidget {
  @override
  _LocalRecordsPageState createState() => _LocalRecordsPageState();
}

class _LocalRecordsPageState extends AppState<LocalRecordsPage> {
  List<dynamic>? _data;
  late ScrollController _scrollController;
  @override
  initState() {
    _scrollController = ScrollController();
    TecfySyncService.getLocalRecords().then((d) {
      _data = d;
      setState(() {});
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['id']);
        _data = await TecfySyncService.getLocalRecords();
        setState(() {});
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, AppLocale.translate(context, 'Local Database'),
        appBarActions: [
          TecfySyncService.isSyncing
              ? CircularProgressIndicator()
              : IconButton(
                  tooltip: trans('Sync'),
                  icon: Icon(Icons.sync_alt),
                  onPressed: () async {
                    TecfySyncService.isSyncing = true;
                    setState(() {});
                    var result =
                        await TecfySyncService.syncNow(context: context);
                    TecfySyncService.isSyncing = false;
                    if (result) {
                      AppNavigator.showMessage(context, 'تمت العملية بنجاح',
                          type: MessageType.success);
                      _data = await TecfySyncService.getLocalRecords();
                    } else {
                      AppNavigator.showMessage(context, 'Error',
                          message: 'خطأ اثناء المزامنه مع السيرفر',
                          type: MessageType.error);
                    }
                    setState(() {});
                  })
        ],
        child: _data == null
            ? Center(child: CircularProgressIndicator())
            : Scrollbar(
                isAlwaysShown: true,
                showTrackOnHover: true,
                controller: _scrollController,
                child: SingleChildScrollView(
                  controller: _scrollController,
                  child: DataTable(
                    showCheckboxColumn: true,
                    sortColumnIndex: 0,
                    sortAscending: false,
                    columns: [
                      DataColumn(label: Text(trans('Entity')), numeric: false),
                      DataColumn(label: Text(trans('Count')), numeric: true),
                    ],
                    rows: _data
                            ?.map<DataRow>((d) => DataRow(
                                  cells: [
                                    DataCell(
                                        Text(d['entityName'] ??
                                            d['entity'] ??
                                            ''),
                                        onTap: () => onTab(d)),
                                    DataCell(Text(d['count'].toString()),
                                        onTap: () => onTab(d)),
                                    // DataCell(Text(d['message'] ?? ''),
                                    //     onTap: () => onTab(d)),
                                  ],
                                ))
                            .toList() ??
                        [],
                  ),
                ),
              ));
  }
}
